pub fn parse_file_category(raw: &str) -> Result<FileCategory>Expand description
Parses a file category from its lowercase string representation.
Errors
Returns an error when raw is not one of the stable FileCategory string values.
pub fn parse_file_category(raw: &str) -> Result<FileCategory>Parses a file category from its lowercase string representation.
Returns an error when raw is not one of the stable FileCategory string values.