pub fn parse_file_category(raw: &str) -> Result<FileCategory>Expand description
Parses a file category from its lowercase string representation.
pub fn parse_file_category(raw: &str) -> Result<FileCategory>Parses a file category from its lowercase string representation.